import * as api from "aws-cdk-lib/aws-apigateway";
import * as iam from "aws-cdk-lib/aws-iam";
import * as lambda from "aws-cdk-lib/aws-lambda";
import * as logs from "aws-cdk-lib/aws-logs";
import * as route53 from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
export interface ApiGatewayToLambdaProps {
    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * User provided props to override the default props for the Lambda function.
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
    /**
     * Optional user-provided props to override the default props for the API.
     */
    readonly apiGatewayProps?: api.LambdaRestApiProps | any;
    /**
     * User provided props to override the default props for the CloudWatchLogs LogGroup.
     */
    /**
     * Optional custom domain configuration for API Gateway.
     *
     * @default - no custom domain
     */
    readonly customDomainName?: string;
    /**
     * Optional Route53 hosted zone to create alias record for the custom domain.
     *
     * @default - no Route53 alias record created
     */
    readonly hostedZone?: route53.IHostedZone;
    /**
     * Whether to create a Usage Plan attached to the API. Must be true if
     * apiGatewayProps.defaultMethodOptions.apiKeyRequired is true
     */
    readonly createUsagePlan?: boolean;
    readonly logGroupProps?: logs.LogGroupProps;
}
/**
 * @summary The ApiGatewayToLambda class.
 */
export declare class ApiGatewayToLambda extends Construct {
    readonly apiGateway: api.RestApi;
    readonly apiGatewayCloudWatchRole?: iam.Role;
    readonly apiGatewayLogGroup: logs.LogGroup;
    readonly lambdaFunction: lambda.Function;
    readonly aRecord?: route53.ARecord;
    /**
     * @param {cdk.App} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {CloudFrontToApiGatewayToLambdaProps} props - user provided props for the construct
     */
    constructor(scope: Construct, id: string, props: ApiGatewayToLambdaProps);
}
